@@ -7,7 +7,7 @@
 # relevant information (tokens, dates, ... ) from some textual sources (SMS,
 # email, tweets, YouTube comments).
 #
-# Copyright (C) 2020 Sing Group (University of Vigo)
+# Copyright (C) 2020-2022 Sing Group (University of Vigo)
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -189,12 +189,12 @@ GenericPipe <- R6Class(
     #'
     hash = function(algo = "md5") {
       x <- lapply(ls(private), function(x) {
-        if (class(private[[x]]) != "function") {
+        if (!inherits((private[[x]]),"function")) {
           private[[x]]
         }
       })
       y <- lapply(ls(self), function(x) {
-        if (class(self[[x]]) != "function") {
+        if (!inherits(self[[x]], "function")) {
           self[[x]]
         }
       })
